@@ -35,18 +35,10 @@ COMPOSITION_KEYWORDS = ("anyOf", "oneOf", "allOf", "not")
 
 
 UNSUPPORTED_SCHEMA_KEYWORDS = {
-    "const",
-    "contains",
     "$defs",
-    "dependencies",
-    "enum",
     "if",
     "then",
     "else",
-    "maxProperties",
-    "minProperties",
-    "propertyNames",
     "unevaluatedItems",
     "unevaluatedProperties",
-    "uniqueItems",
 }
