@@ -1,4 +1,4 @@
-from typing import List, TypeVar, Union
+from typing import Any, List, TypeVar, Union
 
 from statham.dsl.constants import Maybe, NotPassed
 from statham.dsl.elements.base import Element
@@ -9,13 +9,12 @@ from statham.dsl.validation import InstanceOf
 Item = TypeVar("Item")
 
 
+# pylint: disable=too-many-instance-attributes
 class Array(Element[List[Item]]):
     """JSONSchema array element.
 
     Requires schema element for "items" keyword as first positional
     argument. Supported validation keywords provided via keyword arguments.
-    # TODO: unqiueItems
-    # TODO: contains
     """
 
     items: Union[Element[Item], List[Element]]
@@ -24,16 +23,24 @@ class Array(Element[List[Item]]):
         self,
         items: Union[Element[Item], List[Element]],
         *,
-        additionalItems: Union[Element, bool] = True,
         default: Maybe[List] = NotPassed(),
+        const: Maybe[Any] = NotPassed(),
+        enum: Maybe[List[Any]] = NotPassed(),
+        additionalItems: Union[Element, bool] = True,
         minItems: Maybe[int] = NotPassed(),
         maxItems: Maybe[int] = NotPassed(),
+        uniqueItems: bool = False,
+        contains: Maybe[Element] = NotPassed(),
     ):
         self.items = items
-        self.additionalItems = additionalItems
         self.default = default
+        self.const = const
+        self.enum = enum
+        self.additionalItems = additionalItems
         self.minItems = minItems
         self.maxItems = maxItems
+        self.uniqueItems = uniqueItems
+        self.contains = contains
 
     @property
     def annotation(self) -> str:
