@@ -1,13 +1,19 @@
 import keyword
 from typing import Any, Dict, List, Tuple, Type, Union
 
+from statham.dsl.constants import Maybe, NotPassed
 from statham.dsl.elements.base import Element
 from statham.dsl.property import _Property
-from statham.dsl.constants import NotPassed
 from statham.dsl.exceptions import SchemaDefinitionError
 from statham.dsl.validation import (
     AdditionalProperties,
+    Const,
+    Dependencies,
+    Enum,
     InstanceOf,
+    MaxProperties,
+    MinProperties,
+    PropertyNames,
     Required,
     Validator,
 )
@@ -53,6 +59,12 @@ class ObjectMeta(type, Element):
     properties: Dict[str, _Property]
     additionalProperties: Union[Element, bool]
     patternProperties: Dict[str, Element]
+    minProperties: Maybe[int]
+    maxProperties: Maybe[int]
+    propertyNames: Maybe[Element]
+    const: Maybe[Any]
+    enum: Maybe[List[Any]]
+    dependencies: Maybe[Dict[str, Union[List[str], Element]]]
 
     @staticmethod
     def __subclasses__():
@@ -73,9 +85,15 @@ class ObjectMeta(type, Element):
         cls.properties = classdict.properties
         for property_ in cls.properties.values():
             property_.bind_class(cls)
-        cls.default = classdict.default
+        cls.default = classdict.default  # TODO: Make this a class arg.
         cls.additionalProperties = kwargs.get("additionalProperties", True)
         cls.patternProperties = kwargs.get("patternProperties", {})
+        cls.minProperties = kwargs.get("minProperties", NotPassed())
+        cls.maxProperties = kwargs.get("maxProperties", NotPassed())
+        cls.propertyNames = kwargs.get("propertyNames", NotPassed())
+        cls.dependencies = kwargs.get("dependencies", NotPassed())
+        cls.const = kwargs.get("const", NotPassed())
+        cls.enum = kwargs.get("enum", NotPassed())
         return cls
 
     def __hash__(cls):
@@ -94,7 +112,7 @@ class ObjectMeta(type, Element):
 
     @property
     def validators(cls) -> List[Validator]:
-        return [
+        possible_validators = [
             cls.type_validator,
             Required(
                 [
@@ -104,15 +122,34 @@ class ObjectMeta(type, Element):
                 ]
             ),
             AdditionalProperties(cls.__properties__),
+            MinProperties.from_element(cls),
+            MaxProperties.from_element(cls),
+            PropertyNames.from_element(cls),
+            Const.from_element(cls),
+            Enum.from_element(cls),
+            Dependencies.from_element(cls),
         ]
+        return [validator for validator in possible_validators if validator]
 
     def python(cls) -> str:
         super_cls = next(iter(cls.mro()[1:]))
         cls_args = [super_cls.__name__]
+        if not isinstance(cls.const, NotPassed):
+            cls_args.append(f"const={cls.const}")
+        if not isinstance(cls.enum, NotPassed):
+            cls_args.append(f"enum={cls.enum}")
+        if cls.minProperties:
+            cls_args.append(f"minProperties={cls.minProperties}")
+        if not isinstance(cls.maxProperties, NotPassed):
+            cls_args.append(f"maxProperties={cls.maxProperties}")
         if cls.patternProperties:
             cls_args.append(f"patternProperties={cls.patternProperties}")
         if cls.additionalProperties not in (True, Element()):
             cls_args.append(f"additionalProperties={cls.additionalProperties}")
+        if not isinstance(cls.propertyNames, NotPassed):
+            cls_args.append(f"propertyNames={cls.propertyNames}")
+        if not isinstance(cls.dependencies, NotPassed):
+            cls_args.append(f"dependencies={cls.dependencies}")
         class_def = f"""class {repr(cls)}({', '.join(cls_args)}):
 """
         if not cls.properties and isinstance(cls.default, NotPassed):
